BeNiceAnotateThatPlot: BeNiceAnotateThatPlot

Description Usage Examples

Description

Takes an already built ggplot and add text to the right of the main plot, or as a legend underneath.

Usage

1
2
3
BeNiceAnotateThatPlot(dataPlot, anotation = "", anotationType = "right",
  titleAnotation = NULL, titlePlot = NULL, plotIt = T,
  fontFamily = "Calibri", ...)

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
## Not run: 
# Dummy data generation
x = runif(9, 0, 125)
data = as.data.frame(x)
data$y = runif(9, 0, 125) 

# Dummy plot generation
superPlot = ggplot(data, aes(x, y)) +
        geom_point()

# Anotate that dummy plot
annotedPlot = BeNiceAnotateThatPlot(superPlot, anotation = "The beach is pretty nice\nIsn't it ?", titleAnotation = "Title", titlePlot = "Super Nice Title")

## End(Not run)

p15e/BeNice documentation built on May 24, 2019, 5:56 p.m.